/*
|------------------------------------------------------------------------------------------
|------------------------------------------------------------------------------------------
| File Name			  : MicroBoltPwmOutput.c																					
| Author			    : Micromint, Inc.						
| Copyright       : Copyright  2005, Micromint, Inc.																	
| Creation Date		: 4/2/05																							
| Version			    : 1.00																																												
| Spaces per tab	:	2																									
| Description		  : Main C file																																									 
| Revision			  :	Initial																																																						
|------------------------------------------------------------------------------------------
|------------------------------------------------------------------------------------------
*/

/*
|----------------------------------------------------
|     Includes
|----------------------------------------------------
*/

#include <ARM/philips/lpc210x.h>
#include <arm_macros.h>

#include "MicroBoltPwmOutput.h"

/*
|------------------------------------------------------------------------------------------
|     Function        :   main
|     Inputs          :   None
|     Outputs         :   None
|     Purpose         :   Main function for system
|     Author          :   Micromint, Inc.
|------------------------------------------------------------------------------------------
*/

void main(void)
  {

/*
|----------------------------------------------------
|     MicroBolt hardware setup 
|----------------------------------------------------
*/

  __DISABLE_INTERRUPT();                        // Disable all interrupts

  SCB_PLLCFG |= 0x23;				 	   		            // Turn on PLL, set to 59 MHz (0x03 is multiply value of 4)
  SCB_PLLCON |= 0x03;
  SCB_PLLFEED = 0xAA;					   	  	          // Shadow register copy for PLL
  SCB_PLLFEED = 0x55; 

  PCB_PINSEL0=0x00000000;                       // JTAG is via secondary port
  PCB_PINSEL1=0x55400000;
  GPIO_IODIR=(0x00000000<<16)|
	     0x00000000;
 
  GPIO_IOCLR=0xffffffff;
  GPIO_IOSET=(0x00000000<<16)| 
            0x00000000;  

  GPIO_IODIR |= MICROBOLT_LED;                  // Setup MicroBolt LED as output

  PCB_PINSEL0 |= P0_7_PWM_0_2;                  // Setup P0.7 to alternate function PWM0-2

  PWM_PR = 0x00000000;                          // Load prescaler  
  PWM_PCR = 0x00000400;                         // Select PWM2 as single edge and enable the PWM2 output
  PWM_MCR =0x00000000;                          // PWM's are free running, no interrupt  

  PWM_MR0 = 0x00000300;                         // Setup Match register 0 count       
  PWM_MR2 = 0x00000000;                         // Setup Match register 2 count
    
  PWM_LER = 0x0000000F;                         // Enable shadow copy for match registers    
  PWM_TCR = 0x00000002;                         // Reset counter and prescaler            
  PWM_TCR = 0x00000009;                         // Enable PWM and counter

/*
|----------------------------------------------------
|     Start of application
|----------------------------------------------------
*/

  while(1)                                      // Do this forever
    {        
    unsigned int Delay;                      		  

    for (Delay = 0; Delay < 7750; Delay++);       // Delay for 10 mS  

    PWM_MR2 = PWM_MR2 + 1;                      // Increment PWM2 match value
	  PWM_LER = 0x0000000F;                       // Latch new MR2 match value

    if (PWM_MR2 >= PWM_MR0)                     // PWM match greater than or equal to PWM period?
      {
      PWM_MR2 = 0x00000000;                     // Reset match value to 0
	    PWM_LER = 0x0000000F;                     // Latch new MR2 match value
      }  
    }
  }


